Examples
========

List of examples illustrating the use of Solcore. More examples are available in the `Solcore's Github repository (Examples folder) <https://github.com/dalonsoa/solcore5>`_ and will be listed here at some point

Quantum solvers
---------------

- :doc:`Calculating the bandstructure and local density of states in QWs and MQWs <example_QWs>`
- :doc:`KP calculator and effective mass fitting <example_K_and_effective_mass>`

Light sources
-------------

- :doc:`Example of the use of the light_sources module <example_light_sources>`

Optical methods
---------------

- :doc:`Using the TMM solver to calculate the reflextion of a multilayered ARC <example_RAT_of_ARC>`
- :doc:`Looking at the effect of substrate and the no_back_reflection option in the TMM solver <example_substrate>`
- :doc:`Comparing optical models (TMM, Beer-Lambert, and RCWA) <example_optics_comparison>`

Custom materials
----------------

- :doc:`Setting up the options for and defining custom materials <custom_materials_example>`
- :doc:`Searching the refractiveindex.info database and comparing materials <refractiveindex_info_db_example>`

MJ solar cells
--------------

- :doc:`Tutorial: 2J solar cell with QWs in the bottom cell <tutorial>`
- :doc:`Example of a 2J solar cell calculated with the PDD solver <example_PDD_solver>`
- :doc:`Radiative coupling in a 3J solar cell <example_radiative_coupling>`
- :doc:`MJ solar cell efficiency map <example_MJ_efficiency_map>`
- :doc:`Traditional GaInP/InGaAs/Ge solar cell <example_3J_with_DA_solver>`
- :doc:`Example of a tunnel junction <../Examples/example_tunnel_junction>`

SPICE-based solar cell solver
-----------------------------

- :doc:`PV module calculator <example_pv_module>`
- :doc:`Quasi-3D 3J solar cell <example_quasi3D_cell>`

